GKRCircuitProverConfig

Struct GKRCircuitProverConfig 

pub struct GKRCircuitProverConfig {
    lazy_beta_evals: bool,
    circuit_description_hash_type: CircuitHashType,
    claim_agg_strategy: ClaimAggregationStrategy,
    claim_agg_constant_column_optimization: bool,
    hyrax_input_layer_batch_opening: bool,
    enable_bit_packing: bool,
}
A config which informs a GKR circuit prover about how to prove a GKR circuit, including flags e.g. whether to use certain optimizations (e.g. Evaluations memory-efficient optimization), or e.g. which claim aggregation strategy to use.

Fields

lazy_beta_evals: bool

Whether to evaluate the beta function within gate layers lazily, i.e. to compute the values on the fly rather than via initializing a beta evaluations “table”.

circuit_description_hash_type: CircuitHashType

The type of hash function to be used on hashing the circuit description to be added to transcript.

claim_agg_strategy: ClaimAggregationStrategy

Which claim aggregation (RLC vs. deterministic) to use for reducing the validity of multiple claims on a layer to that of a single claim.

claim_agg_constant_column_optimization: bool

Whether to use the “constant column optimization”, i.e. whether to reduce the implicit degree of the prover-claimed polynomial Q(x) =? V_i(l(x)) when there are variable indices within all claims where all challenges within that index are identical.

hyrax_input_layer_batch_opening: bool

Hyrax input layer batch opening. Determines whether we attempt to aggregate Hyrax PCS Evaluation proofs by grouping common challenge coordinates together.

enable_bit_packing: bool

Controls whether bit-packing is actually enabled. If set to false, the BitPackedVector will default to storing each field element using the type F, effectively behaving like a regular (immutable) Vec<F>. This is needed because bit-packing incurs a noticable runtime slowdown, and we need an easy way to turn it off if trading memory for speed is desirable.

Note that because this is global, this option also implicitly affects the verifier’s Evaluations<F> structs!!!

Implementations

Source

impl GKRCircuitProverConfig

pub fn matches_global_prover_config( &self, prover_verifier_config_instance: &RwLockReadGuard<'_, (GKRCircuitProverConfig, GKRCircuitVerifierConfig)>, ) -> bool

Returns whether the calling GKRCircuitProverConfig, i.e. the “expected” config, matches the one which is currently configured globally. A match implies that we are ready to start proving.

Note that the prover_verifier_config_instance should be held for the ENTIRE DURATION of proving (and verifying) to prevent any changes from happening to the config in the middle of proving!

Source

impl GKRCircuitProverConfig

pub fn memory_optimized_default() -> Self

Returns a memory-optimal configuration for the GKR circuit prover.

In particular, this turns on the lazy_beta_evals and bit_packed_vector flags.

pub fn runtime_optimized_default() -> Self

Returns a runtime-optimal configuration for the GKR circuit prover.

pub const fn hyrax_compatible_runtime_optimized_default() -> Self

Returns a runtime-optimal configuration for a version of the GKR circuit prover which is compatible with our current Hyrax IP implementation.

In particular, this turns OFF the enable_bit_packing option, turns OFF the lazy_beta_evals option, and additionally turns OFF the claim_agg_constant_column_optimization option as well.

pub const fn hyrax_compatible_memory_optimized_default() -> Self

Returns a memory-optimal configuration for a version of the GKR circuit prover which is compatible with our current Hyrax IP implementation.

In particular, this turns ON the enable_bit_packing option, turns ON the lazy_beta_evals, and additionally turns OFF the claim_agg_constant_column_optimization option as well.

pub fn new( lazy_beta_evals: bool, circuit_description_hash_type: CircuitHashType, claim_agg_strategy: ClaimAggregationStrategy, claim_agg_constant_column_optimization: bool, hyrax_input_layer_batch_opening: bool, enable_bit_packing: bool, ) -> Self

Constructs a new GKRCircuitProverConfig from scratch.

pub fn set_lazy_beta_evals(&mut self, updated_lazy_beta_evals: bool)

Setter function for lazy beta evals.

pub fn set_claim_agg_strategy( &mut self, updated_claim_agg_strategy: ClaimAggregationStrategy, )

Setter function for claim agg strategy.

pub fn set_circuit_description_hash_type( &mut self, updated_circuit_description_hash_type: CircuitHashType, )

Setter function for circuit hash type.

pub fn set_claim_agg_constant_column_optimization( &mut self, updated_claim_agg_constant_column_optimization: bool, )

Setter function for constant column optimization.

pub fn set_enable_bit_packing(&mut self, updated_enable_bit_packing: bool)

Setter function for enabling bit packing.

pub fn get_lazy_beta_evals(&self) -> bool

Getter function for lazy beta evals.

pub fn get_claim_agg_strategy(&self) -> ClaimAggregationStrategy

Getter function for claim agg strategy.

pub fn get_circuit_description_hash_type(&self) -> CircuitHashType

Getter function for circuit hash type.

pub fn get_claim_agg_constant_column_optimization(&self) -> bool

Getter function for constant column optimization.

pub fn get_hyrax_batch_opening(&self) -> bool

Getter function for Hyrax batch opening.

pub fn get_enable_bit_packing(&self) -> bool

Getter function for enabling bit packing.