pub struct GKRCircuitVerifierConfig {
lazy_beta_evals: bool,
circuit_description_hash_type: CircuitHashType,
claim_agg_strategy: ClaimAggregationStrategy,
claim_agg_constant_column_optimization: bool,
}Expand description
A config which informs a GKR circuit verifier about how to verify a GKR circuit + proof, including flags e.g. how to aggregate claims.
Fields
lazy_beta_evals: boolWhether to evaluate the beta function within gate layers lazily, i.e. to compute the values on the fly rather than via initializing a beta evaluations “table”.
circuit_description_hash_type: CircuitHashTypeThe type of hash function to be used for hashing the circuit description to be added to transcript.
claim_agg_strategy: ClaimAggregationStrategyWhich claim aggregation (RLC vs. deterministic) to use for reducing the validity of multiple claims on a layer to that of a single claim.
claim_agg_constant_column_optimization: boolWhether to use the “constant column optimization”, i.e. whether to reduce the implicit degree of the prover-claimed polynomial Q(x) =? V_i(l(x)) when there are variable indices within all claims where all challenges within that index are identical.
Implementations
Sourceimpl GKRCircuitVerifierConfig
impl GKRCircuitVerifierConfig
Sourcepub fn matches_global_verifier_config(
&self,
prover_verifier_config_instance: &RwLockReadGuard<'_, (GKRCircuitProverConfig, GKRCircuitVerifierConfig)>,
) -> bool
pub fn matches_global_verifier_config( &self, prover_verifier_config_instance: &RwLockReadGuard<'_, (GKRCircuitProverConfig, GKRCircuitVerifierConfig)>, ) -> bool
Returns whether the calling GKRCircuitVerifierConfig, i.e. the “expected” config, matches the one which is currently configured globally. A match implies that we are ready to start verifying.
Note that the prover_verifier_config_instance should be held for
the ENTIRE DURATION of verifying to prevent any changes
from happening to the config in the middle of verifying!
Sourcepub fn matches_proof_config(&self, proof_config: &ProofConfig) -> bool
pub fn matches_proof_config(&self, proof_config: &ProofConfig) -> bool
Returns whether the current (expected) GKRCircuitVerifierConfig matches the ProofConfig for the given proof.
Sourceimpl GKRCircuitVerifierConfig
impl GKRCircuitVerifierConfig
Sourcepub fn new_from_prover_config(
prover_config: &GKRCircuitProverConfig,
verifier_lazy_beta_evals: bool,
) -> Self
pub fn new_from_prover_config( prover_config: &GKRCircuitProverConfig, verifier_lazy_beta_evals: bool, ) -> Self
Constructs a GKRCircuitVerifierConfig from the GKRCircuitProverConfig used for the corresponding prover.
Sourcepub const fn new(
lazy_beta_evals: bool,
circuit_description_hash_type: CircuitHashType,
claim_agg_strategy: ClaimAggregationStrategy,
claim_agg_constant_column_optimization: bool,
) -> Self
pub const fn new( lazy_beta_evals: bool, circuit_description_hash_type: CircuitHashType, claim_agg_strategy: ClaimAggregationStrategy, claim_agg_constant_column_optimization: bool, ) -> Self
Constructs a new GKRCircuitVerifierConfig from scratch.
Sourcepub fn new_from_proof_config(
proof_config: &ProofConfig,
verifier_lazy_beta_evals: bool,
) -> Self
pub fn new_from_proof_config( proof_config: &ProofConfig, verifier_lazy_beta_evals: bool, ) -> Self
Constructs a GKRCircuitVerifierConfig from the corresponding ProofConfig used within the proof.
Sourcepub const fn hyrax_compatible_runtime_optimized_default() -> Self
pub const fn hyrax_compatible_runtime_optimized_default() -> Self
Returns a runtime-optimal configuration for a version of the GKR circuit verifier compatible with Hyrax.
In particular, this turns OFF the lazy_beta_evals, and additionally
turns OFF the claim_agg_constant_column_optimization option as well.
Sourcepub fn set_lazy_beta_evals(&mut self, updated_lazy_beta_evals: bool)
pub fn set_lazy_beta_evals(&mut self, updated_lazy_beta_evals: bool)
Setter function for lazy beta evals.
Sourcepub fn set_claim_agg_strategy(
&mut self,
updated_claim_agg_strategy: ClaimAggregationStrategy,
)
pub fn set_claim_agg_strategy( &mut self, updated_claim_agg_strategy: ClaimAggregationStrategy, )
Setter function for claim agg strategy.
Sourcepub fn set_circuit_description_hash_type(
&mut self,
updated_circuit_description_hash_type: CircuitHashType,
)
pub fn set_circuit_description_hash_type( &mut self, updated_circuit_description_hash_type: CircuitHashType, )
Setter function for circuit hash type.
Sourcepub fn set_claim_agg_constant_column_optimization(
&mut self,
updated_claim_agg_constant_column_optimization: bool,
)
pub fn set_claim_agg_constant_column_optimization( &mut self, updated_claim_agg_constant_column_optimization: bool, )
Setter function for constant column optimization.
Sourcepub fn get_lazy_beta_evals(&self) -> bool
pub fn get_lazy_beta_evals(&self) -> bool
Getter function for lazy beta evals.
Sourcepub fn get_claim_agg_strategy(&self) -> ClaimAggregationStrategy
pub fn get_claim_agg_strategy(&self) -> ClaimAggregationStrategy
Getter function for claim agg strategy.
Sourcepub fn get_circuit_description_hash_type(&self) -> CircuitHashType
pub fn get_circuit_description_hash_type(&self) -> CircuitHashType
Getter function for circuit hash type.
Sourcepub fn get_claim_agg_constant_column_optimization(&self) -> bool
pub fn get_claim_agg_constant_column_optimization(&self) -> bool
Getter function for constant column optimization.