pub struct ProofConfig {
circuit_description_hash_type: CircuitHashType,
claim_agg_strategy: ClaimAggregationStrategy,
claim_agg_constant_column_optimization: bool,
}Expand description
A config which travels alongside a GKR proof stored within a Transcript
which details the proof-specific configuration (i.e. how the verifier
should be configured in order to appropriately parse and verify the proof).
Fields
circuit_description_hash_type: CircuitHashTypeThe type of hash function to be used on hashing the circuit description to be added to transcript.
claim_agg_strategy: ClaimAggregationStrategyWhich claim aggregation (RLC vs. deterministic) to use for reducing the validity of multiple claims on a layer to that of a single claim.
claim_agg_constant_column_optimization: boolWhether to use the “constant column optimization”, i.e. whether to reduce the implicit degree of the prover-claimed polynomial Q(x) =? V_i(l(x)) when there are variable indices within all claims where all challenges within that index are identical.
Implementations
Sourceimpl ProofConfig
impl ProofConfig
Sourcepub fn new_from_prover_config(prover_config: &GKRCircuitProverConfig) -> Self
pub fn new_from_prover_config(prover_config: &GKRCircuitProverConfig) -> Self
Creates the associated ProofConfig from a GKRCircuitProverConfig. Note that a similar function should not be required for a GKRCircuitVerifierConfig, since only the circuit prover should specify the proof config and the verifier should simply check to see if their own config matches that of the proof given.
Sourcepub fn set_claim_agg_strategy(
&mut self,
updated_claim_agg_strategy: ClaimAggregationStrategy,
)
pub fn set_claim_agg_strategy( &mut self, updated_claim_agg_strategy: ClaimAggregationStrategy, )
Setter function for claim agg strategy.
Sourcepub fn set_circuit_description_hash_type(
&mut self,
updated_circuit_description_hash_type: CircuitHashType,
)
pub fn set_circuit_description_hash_type( &mut self, updated_circuit_description_hash_type: CircuitHashType, )
Setter function for circuit hash type.
Sourcepub fn set_claim_agg_constant_column_optimization(
&mut self,
updated_claim_agg_constant_column_optimization: bool,
)
pub fn set_claim_agg_constant_column_optimization( &mut self, updated_claim_agg_constant_column_optimization: bool, )
Setter function for constant column optimization.
Sourcepub fn get_claim_agg_strategy(&self) -> ClaimAggregationStrategy
pub fn get_claim_agg_strategy(&self) -> ClaimAggregationStrategy
Getter function for claim agg strategy.
Sourcepub fn get_circuit_description_hash_type(&self) -> CircuitHashType
pub fn get_circuit_description_hash_type(&self) -> CircuitHashType
Getter function for circuit hash type.
Sourcepub fn get_claim_agg_constant_column_optimization(&self) -> bool
pub fn get_claim_agg_constant_column_optimization(&self) -> bool
Getter function for constant column optimization.